Christoph von Wittich : comctl32: Rename TBSTYLE_EX_UNDOC1 to TBSTYLE_EX_VERTICAL.

Alexandre Julliard julliard at winehq.org
Mon Feb 24 15:42:31 CST 2014


Module: wine
Branch: master
Commit: 37e0a1a5d4977a5f017709109dd6cf7a948b78e8
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=37e0a1a5d4977a5f017709109dd6cf7a948b78e8

Author: Christoph von Wittich <Christoph at ApiViewer.de>
Date:   Sat Feb 22 21:02:22 2014 +0100

comctl32: Rename TBSTYLE_EX_UNDOC1 to TBSTYLE_EX_VERTICAL.

---

 dlls/comctl32/toolbar.c |    8 ++++----
 include/commctrl.h      |    3 ++-
 2 files changed, 6 insertions(+), 5 deletions(-)

diff --git a/include/commctrl.h b/include/commctrl.h
index 0f153e4..9993ec7 100644
--- a/include/commctrl.h
+++ b/include/commctrl.h
@@ -1089,7 +1089,8 @@ static const WCHAR TOOLBARCLASSNAMEW[] = { 'T','o','o','l','b','a','r',
 #define TBSTYLE_REGISTERDROP    0x4000
 #define TBSTYLE_TRANSPARENT     0x8000
 #define TBSTYLE_EX_DRAWDDARROWS         0x00000001
-#define TBSTYLE_EX_UNDOC1               0x00000004 /* similar to TBSTYLE_WRAPABLE */
+#define TBSTYLE_EX_MULTICOLUMN          0x00000002
+#define TBSTYLE_EX_VERTICAL             0x00000004
 #define TBSTYLE_EX_MIXEDBUTTONS         0x00000008
 #define TBSTYLE_EX_HIDECLIPPEDBUTTONS   0x00000010 /* don't show partially obscured buttons */
 #define TBSTYLE_EX_DOUBLEBUFFER         0x00000080 /* Double Buffer the toolbar */




More information about the wine-cvs mailing list
diff --git a/dlls/comctl32/toolbar.c b/dlls/comctl32/toolbar.c
index b523dc0..fb82961 100644
--- a/dlls/comctl32/toolbar.c
+++ b/dlls/comctl32/toolbar.c
@@ -219,7 +219,7 @@ typedef enum
 
 /* Used to find undocumented extended styles */
 #define TBSTYLE_EX_ALL (TBSTYLE_EX_DRAWDDARROWS | \
-                        TBSTYLE_EX_UNDOC1 | \
+                        TBSTYLE_EX_VERTICAL | \
                         TBSTYLE_EX_MIXEDBUTTONS | \
                         TBSTYLE_EX_DOUBLEBUFFER | \
                         TBSTYLE_EX_HIDECLIPPEDBUTTONS)
@@ -1271,7 +1271,7 @@ TOOLBAR_CalcStrings (const TOOLBAR_INFO *infoPtr, LPSIZE lpSize)
 * the toolbar wrapping on its own, it can use the TBSTYLE_WRAPABLE
 * flag, and set the TBSTATE_WRAP flags manually on the appropriate items.
 *
 * Note: TBSTYLE_WRAPABLE or TBSTYLE_EX_UNDOC1 can be used also to allow
 * vertical toolbar lists.
 */
 
@@ -1287,7 +1287,7 @@ TOOLBAR_WrapToolbar(TOOLBAR_INFO *infoPtr)
     /*	no layout is necessary. Applications may use this style */
     /*	to perform their own layout on the toolbar. 		*/
     if( !(infoPtr->dwStyle & TBSTYLE_WRAPABLE) &&
-	!(infoPtr->dwExStyle & TBSTYLE_EX_UNDOC1) )  return;
+	!(infoPtr->dwExStyle & TBSTYLE_EX_VERTICAL) )  return;
 
     btnPtr = infoPtr->buttons;
     x  = infoPtr->nIndent;
@@ -3037,7 +3037,7 @@ TOOLBAR_AutoSize (TOOLBAR_INFO *infoPtr)
     cy = TOP_BORDER + infoPtr->nRows * infoPtr->nButtonHeight + BOTTOM_BORDER;
     cx = parent_rect.right - parent_rect.left;
 
-    if ((infoPtr->dwStyle & TBSTYLE_WRAPABLE) || (infoPtr->dwExStyle & TBSTYLE_EX_UNDOC1))
+    if ((infoPtr->dwStyle & TBSTYLE_WRAPABLE) || (infoPtr->dwExStyle & TBSTYLE_EX_VERTICAL))
     {
         TOOLBAR_LayoutToolbar(infoPtr);
         InvalidateRect( infoPtr->hwndSelf, NULL, TRUE );
@@ -1271,7 +1271,7 @@ TOOLBAR_CalcStrings (const TOOLBAR_INFO *infoPtr, LPSIZE lpSize)
 * flag, and set the TBSTATE_WRAP flags manually on the appropriate items.
 *
-* Note: TBSTYLE_WRAPABLE or TBSTYLE_EX_UNDOC1 can be used also to allow
+* Note: TBSTYLE_WRAPABLE or TBSTYLE_EX_VERTICAL can be used also to allow
 * vertical toolbar lists.
 */